import { ElementRef, EventEmitter, AfterViewInit, OnDestroy, NgZone } from '@angular/core';
import { CodemirrorService } from './codemirror.service';
/**
 * CodeMirror component
 *
 * **Usage** :
 * ```html
 *   <ngx-codemirror [(ngModel)]="data" [config]="{...}" (init)="onInit" (blur)="onBlur" (focus)="onFocus" ...></ngx-codemirror>
 * ```
 */
export declare class CodemirrorComponent implements AfterViewInit, OnDestroy {
    private _codeMirror;
    private _zone;
    /** Codemirror config object (see [details](http://codemirror.net/doc/manual.html#config)) */
    config: any;
    /** change output event, pass through from codemirror */
    change: EventEmitter<{}>;
    /** focus output event, pass through from codemirror */
    focus: EventEmitter<{}>;
    /** blur output event, pass through from codemirror */
    blur: EventEmitter<{}>;
    /** cursorActivity output event, pass through from codemirror */
    cursorActivity: EventEmitter<{}>;
    /** Host element for codemirror to attach to */
    host: ElementRef;
    /** Current editor instance */
    private _instance;
    /** Value storage */
    private _value;
    /**
     * Constructor
     *
     * @param _zone NgZone injected for Initialization
     */
    constructor(_codeMirror: CodemirrorService, _zone: NgZone);
    /** Implements ControlValueAccessor.value */
    /** Implements ControlValueAccessor.value */
    value: string;
    /**
     * On component destroy
     */
    ngOnDestroy(): void;
    /**
     * On component view init
     */
    ngAfterViewInit(): void;
    /**
     * Value update process
     */
    updateValue(value: any): void;
    /**
     * Implements ControlValueAccessor
     */
    writeValue(value: any): void;
    /** Change event trigger */
    onChange(_: any): void;
    /** Dirty/touched event trigger */
    onTouched(): void;
    /** Implements ControlValueAccessor.registerOnChange */
    registerOnChange(fn: any): void;
    /** Implements ControlValueAccessor.registerOnTouched */
    registerOnTouched(fn: any): void;
    /**
     * Initialize codemirror
     */
    private codemirrorInit(config);
}
